#ifndef CONFIG_H
#define CONFIG_H

/* use faster resampler (uses more memory) */
#define RESAMPLE_FULL_SINC_TABLE 1

#define OPE_BUILD

#define PACKAGE_NAME "libopusenc"

#include "version.h"

#endif /* CONFIG_H */
